==========================
Django Chuck contributors
==========================

Thanks to all who contributed to Django Chuck! :)

* `msabramo <https://github.com/msabramo>`_
* `evildmp <https://github.com/evildmp>`_
